@@ -18,15 +18,18 @@ QueueView::QueueView(Spotify::Session* pSession, QWidget* parent)
     m_currQueuePos = 0;
 
     //define slider used for displaying buffering and track progress
-    m_pProgressSlider = new CustomSlider(this,700,35);
-    m_pProgressSlider->setP1Color(QColor(190,190,190)); //gray (buffering progress)
-    m_pProgressSlider->setP2Color(QColor(0,0,255)); //blue (track progress)
+    m_pProgressSlider = new CustomSlider(this,510,40);
+    m_pProgressSlider->setBgColor(QColor(51,51,51)); //background color of progress slider
+    m_pProgressSlider->setP1Color(QColor(8,117,189)); //color of buffering progress bar
+    m_pProgressSlider->setP2Color(QColor(41,166,241)); //color of track progress bar
+    m_pProgressSlider->setTextColor(QColor(255,255,255)); //set text color to white
     m_pProgressSlider->setPos1(0);
     m_pProgressSlider->setPos2(0);
 
-    m_pSpectrum = new SpectrumAnalyzer(this,50,35);
+    m_pSpectrum = new SpectrumAnalyzer(this,55,40);
     m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
 
+    //set up signal and slot connections
     connect(m_pSession,SIGNAL(trackPositionUpdated(qint64)),SLOT(OnTrackPosUpdated(qint64)));
     connect(m_pSession,SIGNAL(playbackPositionUpdated(qint64)),SLOT(OnPlaybackPositionUpdated(qint64)));
     connect(m_pSession,SIGNAL(coverArtReady(QImage)),SLOT(OnAlbumCoverReady(QImage)));
@@ -39,46 +42,59 @@ QueueView::QueueView(Spotify::Session* pSession, QWidget* parent)
 
 
     m_TrackInfo.setWordWrap(true);
-    m_ArtistName.setWordWrap(true);
+    m_ArtistName.setFixedWidth(300);
+    m_ArtistName.setAlignment(Qt::AlignLeft); //left align artist name
+    m_AlbumCoverContainer.setFixedSize(300,295);
+    m_TrackInfo.setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
 
     //style the player control buttons
     m_PauseResumeBtn.setCheckable(true); //toggle button (between pause / resume states)
     m_PauseResumeBtn.setEnabled(false);
 
     m_PauseResumeBtn.setStyleSheet(
-            "QPushButton {max-height: 64px;}"
-            "QPushButton {min-height: 64px;}"
-            "QPushButton {max-width: 64px;}"
-            "QPushButton {min-width: 64px;}"
+            "QPushButton {max-height: 48px;}"
+            "QPushButton {min-height: 48px;}"
+            "QPushButton {max-width: 48px;}"
+            "QPushButton {min-width: 48px;}"
             "QPushButton {border-style: none;}"
             "QPushButton {background-image: url(/usr/share/images/play.png);}"
-            "QPushButton:on {background-image: url(/usr/share/images/pause.png);}");
+            "QPushButton:on {background-image: url(/usr/share/images/pause.png);}"
+            "QPushButton:pressed {background-image: url(/usr/share/images/play-on.png);}");
 
-    m_PrevBtn.setStyleSheet("min-width: 64px; min-height: 64px; max-width: 64px; max-height: 64px; border-style: none; background-image: url(/usr/share/images/rew.png);");    
-m_NextBtn.setStyleSheet("min-width: 64px; min-height: 64px; max-width: 64px; max-height: 64px;border-style: none; background-image: url(/usr/share/images/fwd.png);");
+    m_PrevBtn.setStyleSheet("QPushButton {min-width: 48px; min-height: 48px; max-width: 48px; max-height: 48px; border-style: none; background-image: url(/usr/share/images/previous.png);}"
+                            "QPushButton:pressed {background-image: url(/usr/share/images/previous-on.png);}");
 
+    m_NextBtn.setStyleSheet("QPushButton {min-width: 48px; min-height: 48px; max-width: 48px; max-height: 48px;border-style: none; background-image: url(/usr/share/images/next.png);}"
+                            "QPushButton:pressed {background-image: url(/usr/share/images/next-on.png);}");
+
+    //sub-layout containing album coverart and artist name
     m_AlbumLayout.addWidget(&m_AlbumCoverContainer);
+    m_AlbumLayout.addSpacing(10);
     m_AlbumLayout.addWidget(&m_ArtistName);
+    m_AlbumLayout.setContentsMargins(5,0,0,0);
 
+    //sub-layout containing player controls, progress slider and spectrum analyzer
+    m_PlayControls.addWidget(&m_PrevBtn,0,0);
+    m_PlayControls.addWidget(&m_PauseResumeBtn,0,1);
+    m_PlayControls.addWidget(&m_NextBtn,0,2);
+    m_PlayControls.addWidget(m_pProgressSlider,0,3,1,1);
+    m_PlayControls.setColumnMinimumWidth(3,510);
+    m_PlayControls.addWidget(m_pSpectrum,0,4,1,1,Qt::AlignRight);
+    m_PlayControls.setColumnStretch(2,10);
+    m_PlayControls.setContentsMargins(0,5,0,5);
 
-    m_PlayControls.addWidget(&m_PrevBtn);
-    m_PlayControls.addWidget(&m_PauseResumeBtn);
-    m_PlayControls.addWidget(&m_NextBtn);
+    m_BottomArea.setStyleSheet("background-image: url(/usr/share/images/bg-toolbar.png);");
+    m_BottomArea.setLayout(&m_PlayControls);
 
     //set up the QueueView UI layout
-    m_GridLayout.addLayout(&m_AlbumLayout,0,0);
-    m_GridLayout.addWidget(&m_TrackInfo,0,1,3,1);
-    m_GridLayout.addLayout(&m_PlayControls,3,0);
-    m_GridLayout.addWidget(&m_CurrTrackPosLabel,3,1,1,1,Qt::AlignRight);
-    m_GridLayout.addWidget(m_pProgressSlider,4,0,1,2);
-    m_GridLayout.addWidget(m_pSpectrum,4,1,1,1,Qt::AlignRight);
-
+    m_GridLayout.addLayout(&m_AlbumLayout,0,0,7,1);
+    m_GridLayout.addWidget(&m_TrackInfo,0,1,7,1);
+    m_GridLayout.addWidget(&m_BottomArea,7,0,1,-1);
+    m_GridLayout.setContentsMargins(0,5,0,0); //set layout margin
 
     m_MainLayout.setLayout(&m_GridLayout);
 
     setCentralWidget(&m_MainLayout);
-
-
 }
 
 QueueView::~QueueView()
@@ -124,7 +140,7 @@ void QueueView::OnPlayingState(bool state)
     }
     else
     { //paused state
-        m_pSpectrum->Stop();
+       m_pSpectrum->Stop();
     }
 }
 
@@ -132,25 +148,39 @@ void QueueView::loadTrackData(Spotify::Track* track)
 {
     //Load track data for specified track (e.g., album cover art)
 
-    if(track->getArtist())
-    {
-           m_ArtistName.setText(track->getArtist()->getName());
-    }
-    if(track->getAlbum())
-    {
-      
-        if(!track->getAlbum()->getImage().isNull()) //album cover already loaded
-        {
-            m_AlbumCoverContainer.setPixmap(QPixmap::fromImage(track->getAlbum()->getImage()));
-        }
-        else
-        {
-             m_pSession->getAlbumCover(track->getAlbum()); //request to load album coverart
-        }
-       
-    }
+    QString strCurrTrackDuration, strCurrTrackProgressInfo;
+    QTextStream outStream(&strCurrTrackProgressInfo);
 
-    m_currTrackDuration = track->getDuration().hour()*3600+track->getDuration().minute()*60+track->getDuration().second(); //current track duration (in secs)
+    if(track)
+    {
+
+        if(track->getArtist())
+        {
+               m_ArtistName.setText(track->getArtist()->getName());
+        }
+        if(track->getAlbum())
+        {
+
+            if(!track->getAlbum()->getImage().isNull()) //album cover already loaded
+            {
+                m_AlbumCoverContainer.setPixmap(QPixmap::fromImage(track->getAlbum()->getImage()));
+            }
+            else
+            {
+                 m_pSession->getAlbumCover(track->getAlbum()); //request to load album coverart
+            }
+
+        }
+
+        m_currTrackDuration = track->getDuration().hour()*3600+track->getDuration().minute()*60+track->getDuration().second(); //current track duration (in secs)
+
+        if(track->getDuration().hour()>0) //duration longer than 60 mins
+            strCurrTrackDuration = track->getDuration().toString("h:mm:ss");
+        else
+            strCurrTrackDuration = track->getDuration().toString("m:ss");
+        outStream << "0:00" << " / " << strCurrTrackDuration;
+        m_pProgressSlider->setText(strCurrTrackProgressInfo);
+    }
 }
 
 void QueueView::addTracks(QList<Spotify::Track*> trackList)
@@ -158,8 +188,13 @@ void QueueView::addTracks(QList<Spotify::Track*> trackList)
     //add tracks from specified list to main listview.
     //Overriden method.
 
+    QPixmap iconMap;
     QString strItemTxt;
 
+    iconMap.load("/usr/share/images/icon-type-song.png"); //load song (track) type icon from file
+
+    QIcon trackTypeIcon(iconMap);
+
     QTextStream txtStream(&strItemTxt);
 
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
@@ -173,15 +208,16 @@ void QueueView::addTracks(QList<Spotify::Track*> trackList)
              if(currTrack)
              {
                  strItemTxt = "";
-                 txtStream << currTrack->getName() << " "; 
-				 if(currTrack->getDuration().hour()>0)
-				 { //track duration longer than 60 mins
-				   txtStream << currTrack->getDuration().toString("(h:mm:ss)");
-				 }
-				 else
-				 {
-				    txtStream << currTrack->getDuration().toString("(m:ss)");
-				 }	 
+                 txtStream << currTrack->getName() << " ";
+                 if(currTrack->getDuration().hour()>0)
+                 { //track duration longer than 60 mins
+                     txtStream << currTrack->getDuration().toString("(h:mm:ss)");
+                 }
+                 else
+                 {
+                     txtStream << currTrack->getDuration().toString("(m:ss)");
+                 }
+                 trackInfo->setIcon(trackTypeIcon);
                  trackInfo->setText(strItemTxt);
                  m_TrackInfo.addItem(trackInfo);
              }
@@ -230,10 +266,9 @@ void QueueView::OnTrackActivated(QListWidgetItem *currTrack)
 
 void QueueView::OnTrackPosUpdated(qint64 trackPos)
 {
-    //track position has been updated (during playback)
+    //Track buffering position has been updated
 
-
-    int currPos = (trackPos*700) / (m_currTrackDuration*1000);
+    int currPos = (trackPos*510) / (m_currTrackDuration*1000);
 
     m_pProgressSlider->setPos1(currPos); //set curr. slider position
 
@@ -241,29 +276,31 @@ void QueueView::OnTrackPosUpdated(qint64 trackPos)
 
 void QueueView::OnPlaybackPositionUpdated(qint64 trackPos)
 {
+    //Track playback position updated
 
     QString strCurrTrackProgressInfo, strCurrPlaybackPos, strCurrTrackDuration;
-	
 
     QTextStream outStream(&strCurrTrackProgressInfo);
 
     QTime currTrackPos(0,trackPos/60000,(trackPos/1000)%60,0);
 
+    qApp->processEvents(); //process any pending events
+
     if(m_pCurrTrack)
     { //set track progress info in format current playback position / total track duration
-	    if(currTrackPos.hour()>0) 
-		    strCurrPlaybackPos = currTrackPos.toString("h:mm:ss"); //position exceeds 60 mins
-		else
-		    strCurrPlaybackPos = currTrackPos.toString("m:ss");
-		if(m_pCurrTrack->getDuration().hour()>0) //duration longer than 60 mins
-		    strCurrTrackDuration = m_pCurrTrack->getDuration().toString("h:mm:ss");
-		else
-			strCurrTrackDuration = m_pCurrTrack->getDuration().toString("m:ss");
-        outStream << strCurrPlaybackPos << " / " << strCurrTrackDuration;
-        m_CurrTrackPosLabel.setText(strCurrTrackProgressInfo);
+            if(currTrackPos.hour()>0)
+                strCurrPlaybackPos = currTrackPos.toString("h:mm:ss"); //position exceeds 60 mins
+            else
+                strCurrPlaybackPos = currTrackPos.toString("m:ss");
+            if(m_pCurrTrack->getDuration().hour()>0) //duration longer than 60 mins
+                strCurrTrackDuration = m_pCurrTrack->getDuration().toString("h:mm:ss");
+            else
+                strCurrTrackDuration = m_pCurrTrack->getDuration().toString("m:ss");
+            outStream << strCurrPlaybackPos << " / " << strCurrTrackDuration;
+            m_pProgressSlider->setText(strCurrTrackProgressInfo);
     }
 
-    int currPos = (trackPos*700) / (m_currTrackDuration*1000);
+    int currPos = (trackPos*510) / (m_currTrackDuration*1000);
 
     m_pProgressSlider->setPos2(currPos); //set curr. slider position
 }
@@ -375,12 +412,12 @@ void QueueView::OnTrackPlaybackFinished()
         m_PauseResumeBtn.setEnabled(false);
         m_pProgressSlider->setPos1(0);
         m_pProgressSlider->setPos2(0);
+        emit playQueuePosUpdated(-1); //emit pos updated (indicates that playqueue has reached the end)
     }
 }
 
 void QueueView::OnAlbumCoverReady(QImage image)
 {
     //Album coverart has been loaded (for currently selected track)
-
     m_AlbumCoverContainer.setPixmap(QPixmap::fromImage(image));
 }
