@@ -67,6 +67,8 @@ Spotify::Session::Session( QObject* parent ):
 
     m_pProcEvtTimer = new QTimer(this);
 
+    m_pAudioThread = NULL;
+
     connect(m_pProcEvtTimer,SIGNAL(timeout()),this,SLOT(OnProcessThreadEvents()),Qt::QueuedConnection);
 
 }
@@ -124,7 +126,10 @@ void Spotify::Session::OnProcessThreadEvents()
     
    do
    {
-    sp_session_process_events(m_session,&next_timeout);
+       if(m_session)
+       {
+            sp_session_process_events(m_session,&next_timeout);
+       }
    }
    while(!next_timeout);
 
@@ -588,9 +593,12 @@ Spotify::Session::~Session()
     m_ProcessEvents = false;
     if(m_currentUser)
         m_currentUser->deleteLater();
-    m_pAudioThread->stop();
-    m_pAudioThread->wait(); //wait for thread execution to finish
-    qDebug() << "Deleting session";
+    if(m_pAudioThread)
+    {
+        m_pAudioThread->stop();
+        m_pAudioThread->wait(); //wait for thread execution to finish
+    }
+    qDebug() << "Session deleted";
 }
 
 
@@ -1182,12 +1190,12 @@ void Spotify::Session::OnResumeBuffering()
 
 void Spotify::Session::playTokenLostCallback( sp_session* session )
 {
-    Q_UNUSED( session );
     Spotify::Session::callingSession->playTokenLostWrapper( session );
 }
 
 void Spotify::Session::playTokenLostWrapper( sp_session* session )
 {
+    //emit signal when playback token has been lost (e.g., same account logs in somewhere else)
     Q_UNUSED( session );
     emit playTokenLost();
 }
@@ -1215,6 +1223,5 @@ void Spotify::Session::endOfTrackWrapper()
     g_audio_mutex.lock();
     g_endOfTrack = true;
     g_audio_mutex.unlock();
-
 }
 
